/*
 * Copyright (c) 2008--2017 by Jeffrey Ratcliffe <jffry@posteo.net>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the same terms as Perl itself, either Perl version 5.8.5 or,
 * at your option, any later version of Perl 5 you may have available.
 */

#ifndef _SANEPERL_H_
#define _SANEPERL_H_

/* Include all of sane's headers for internal consistency */
#include <sane/sane.h>
/*#include "sane/sanei.h"*/
#include "sane/saneopts.h"

#endif /* _SANEPERL_H_ */
